.. _users-guide-index:

############
User's Guide
############

.. only:: html

    :Release: |version|
    :Date: |today|

.. toctree::
    :maxdepth: 2

    installing.rst
    ../tutorials/index.rst
    interactive.rst
    whats_new.rst
    history.rst
    github_stats.rst
    whats_new_old.rst
    license.rst
    ../citing.rst
    credits.rst
